# all imports needed by the client
from direct.showbase.DirectObject import DirectObject
from direct.distributed.ClientRepository import ClientRepository
from pandac.PandaModules import URLSpec
from Message import Message
# the client repository class
class SNCClientRepository(ClientRepository):
    def __init__(self):
        # list of all needed .dc files
        dcFileNames = ['direct.dc', 'net.dc']
        # initialise the client repository on this
        # machine with the dc filenames
        ClientRepository.__init__(self, dcFileNames = dcFileNames)

# the main client class
class Client(DirectObject):
    """The main client class, which contains all the logic
    and stuff you can see in the application and handles the
    connection to the server"""
    def __init__(self, ip):
        """ Default constructor for the Clinet class """
        # msg is the class which will be send over the Network
        # to transmit our messages
        self.msg = None
        # get the port number from the configuration file
        # if it doesn't exist, use 4400 as the default
        tcpPort = base.config.GetInt('server-port', 4400)
        # get the host name from the configuration file
        # which we want to connect to. If it doesn't exit
        # we use loopback to connect to
        hostname = base.config.GetString('server-host', ip)
        # now build the url from the data given above
        self.url = URLSpec('http://%s:%s' % (hostname, tcpPort))

        # create the Repository for the client
        self.cr = SNCClientRepository()
        # and finaly try to connect to the server
        self.cr.connect([self.url],
                        successCallback = self.connectSuccess,
                        failureCallback = self.connectFailure)

    def connectFailure(self, statusCode, statusString):
        """ some error occured while try to connect to the server """
        raise Exception('Failed to connect to %s: %s.'
                        % (self.url, statusString))

    def connectSuccess(self):
        """ Successfully connected.  But we still can't really do
        anything until we've got the doID range. """
        print 'Connection established, waiting for server.'
        # now wait until the server sends us the createReady message
        self.acceptOnce('createReady', self.createReady)
        #self.acceptOnce("getDeck{}".format(self.cr.doIdBase), self.getDeck)

    def createReady(self):
        """ Now we're ready to go! """
        # create a instance of the message class
        msg = Message(self.cr)
        # and create the distributed Object with it
        self.cr.createDistributedObject(
            distObj = msg, zoneId = 1)
        # save the created Distributed Object
        # in self.msg for later usage
        self.msg = msg

        self.accept("sendMessage", self.send)

        self.dShuffle = self.cr.createDistributedObject(
            className = "DistributedShuffle", zoneId = 1)

    def send(self, msg):
        """Function to call the send function of the message class,
        which sends the Message over the Network to the other users"""
        if msg.startswith("GET_CARD_OPTION:"):
            # CHECK only send msg to other client not to self!
            self.msg.d_sendText(msg)
        elif msg.startswith("OPPONENT_IS_ONLINE"):
            # This message is only to check if an opponent is online
            self.msg.d_sendText(msg)
        else:
            self.msg.b_sendText(msg)
