from direct.distributed.DistributedObjectAI import DistributedObjectAI

class DistributedShuffleAI(DistributedObjectAI):

    """ This is the AI-side implementation of DistributedShuffle. """

    def __init__(self, air):
        """Basic init function of the AI class. Requires an AI-
        Repository as parameter"""
        DistributedObjectAI.__init__(self, air)
        self.decks = []
        self.nextFree = 0
        self.startTurn = False

    def requestDeck(self, context):
        """This function is called for each client that requests a card
        deck. It then selects a deck and send an update back to the
        client"""
        requesterId = self.air.getAvatarIdFromSender()
        if self.decks != []:
            print "request deck by ID:", requesterId
            # send the next free deck to the client that requested it
            self.sendUpdateToAvatarId(requesterId, "updateDeck",
                                      [context,
                                       self.decks[self.nextFree],
                                       int(self.startTurn)])
            self.nextFree += 1
            self.startTurn = not self.startTurn
            if len(self.decks) <= self.nextFree:
                # All decks have been used, so request new ones
                print "Request new deck"
                self.nextFree = 0
                base.messenger.send("requestDecks")

    def setDecks(self, decks):
        """This function is used to set a new complete deck for the game
        and has to be called before any other functions are used as
        otherwise no deck will be available"""
        self.decks = decks
