from direct.gui.DirectGui import DirectButton
from direct.gui.DirectGui import DirectEntry
from direct.gui.DirectGui import DirectFrame
from direct.gui.DirectGui import DirectLabel
from direct.showbase.DirectObject import DirectObject
from panda3d.core import TextNode
from panda3d.core import Vec3

class MainMenu(DirectObject):
	"""This class represents the main menu as seen directly after the
	application has been started"""
	def __init__(self):

		# create a main frame as big as the window
		self.frameMain = DirectFrame(
			# set framesize the same size as the window
			frameSize = (base.a2dLeft, base.a2dRight,
						 base.a2dTop, base.a2dBottom),
			# position center
			pos = (0, 0, 0),
			# set tramsparent background color
			frameColor = (0, 0, 0, 1))

		# create the title
		self.textscale = 0.15
		self.title = DirectLabel(
			scale = self.textscale,
			pos = (0.0, 0.0, base.a2dTop - self.textscale),
			frameColor = (0, 0, 0, 0),
			text = "Simple Net Cards",
			text_align = TextNode.ACenter,
			text_fg = (1,1,1,1))
		self.title.setTransparency(1)
		self.title.reparentTo(self.frameMain)

		# create a host button
		self.btnHostPos = Vec3(0, 0, .45)
		self.btnHostScale = 0.25
		self.btnHost = DirectButton(
			scale = self.btnHostScale,
			text = "Host",
			# position on the window
			pos = self.btnHostPos,
			# the event which is thrown on clickSound
			command = self.host,
			# sounds that should be played
			rolloverSound = None,
			clickSound = None)
		self.btnHost.setTransparency(1)
		self.btnHost.reparentTo(self.frameMain)

		# create a join button
		self.btnJoinPos = Vec3(0, 0, 0)
		self.btnJoinScale = 0.25
		self.btnJoin = DirectButton(
			scale = self.btnJoinScale,
			text = "Join",
			# position on the window
			pos = self.btnJoinPos,
			# the event which is thrown on clickSound
			command = self.join,
			# sounds that should be played
			rolloverSound = None,
			clickSound = None)
		self.btnJoin.setTransparency(1)
		self.btnJoin.reparentTo(self.frameMain)

		# Load a monospace font and create the IP input field
		monospace = loader.loadFont('Data/DejaVuSansMono.ttf')
		self.txtIPPos = Vec3(0, 0, -.25)
		self.txtIPScale = 0.1
		self.txtIPWidth = 9
		self.txtIP = DirectEntry(
			entryFont = monospace,
			text = "",
			scale = self.txtIPScale,
			width = self.txtIPWidth,
			pos = self.txtIPPos,
			command = self.join,
			initialText = "127.0.0.1",
			numLines = 1,
			focusInCommand = self.clearText)
		self.txtIP.reparentTo(self.frameMain)

		# create an exit button
		self.btnExitPos = Vec3(0, 0, -.75)
		self.btnExitScale = 0.25
		self.btnExit = DirectButton(
			scale = self.btnExitScale,
			text = "Exit",
			# position on the window
			pos = self.btnExitPos,
			# the event which is thrown on clickSound
			command = lambda: base.messenger.send("quit"),
			# sounds that should be played
			rolloverSound = None,
			clickSound = None)
		self.btnExit.setTransparency(1)
		self.btnExit.reparentTo(self.frameMain)

		# catch window resizes and recalculate the aspectration
		self.accept('window-event', self.recalcAspectRatio)

	def host(self):
		"""Function which will be called by pressing the host button"""
		self.hide()
		base.messenger.send("host")

	def join(self):
		"""Function which will be called by pressing the join button"""
		self.hide()
		base.messenger.send("join", [self.txtIP.get(True)])

	def show(self):
		"""Show the GUI"""
		self.frameMain.show()

	def hide(self):
		"""Hide the GUI"""
		self.frameMain.hide()

	def clearText(self):
		"""Function to clear the text that was previously entered in the
		IP input field"""
		self.txtIP.enterText("")

	def recalcAspectRatio(self, window):
		"""get the new aspect ratio to resize the mainframe"""
		# set the mainframe size to the window borders again
		self.frameMain["frameSize"] = (
			base.a2dLeft, base.a2dRight,
			base.a2dTop, base.a2dBottom)

		# calculate new aspec tratio
		wp = window.getProperties()
		aspX = 1.0
		aspY = 1.0
		wpXSize = wp.getXSize()
		wpYSize = wp.getYSize()
		if wpXSize > wpYSize:
			aspX = wpXSize / float(wpYSize)
		else:
			aspY = wpYSize / float(wpXSize)
		# calculate new position/size/whatever of the gui items
		self.btnJoin.setPos(self.btnJoinPos.getX() * aspX,
							self.btnJoinPos.getY(),
							self.btnJoinPos.getZ() * aspY)
		self.btnHost.setPos(self.btnHostPos.getX() * aspX,
							self.btnHostPos.getY(),
							self.btnHostPos.getZ() * aspY)
		self.txtIP.setPos((self.txtIPPos.getX()-0.2)  * aspX,
							self.txtIPPos.getY(),
							self.txtIPPos.getZ() * aspY)
		self.btnExit.setPos(self.btnExitPos.getX() * aspX,
							self.btnExitPos.getY(),
							self.btnExitPos.getZ() * aspY)
		self.title.setPos(0.0, 0.0, base.a2dTop - self.textscale)

