from direct.distributed.ClientRepository import ClientRepository
from pandac.PandaModules import URLSpec

class ShuffleAIRepository(ClientRepository):
    """ShuffleAIRepository is a small client only for the Server, which
    holds the shuffled card decks"""
    def __init__(self):
        dcFileNames = ['direct.dc', 'net.dc']

        ClientRepository.__init__(self, dcFileNames = dcFileNames,
                                  dcSuffix = 'AI')

        tcpPort = base.config.GetInt('server-port', 4400)
        url = URLSpec('http://127.0.0.1:%s' % (tcpPort))
        self.connect([url],
                     successCallback = self.connectSuccess,
                     failureCallback = self.connectFailure)

    def connectFailure(self, statusCode, statusString):
        raise StandardError, statusString

    def connectSuccess(self):
        """ Successfully connected.  But we still can't really do
        anything until we've got the doID range. """
        print "start now"
        self.acceptOnce('createReady', self.createReady)

    def createReady(self):
        """ Now we're ready to go! """
        self.shuffledDeck = self.createDistributedObject(
            className = 'DistributedShuffleAI', zoneId = 1)
        base.messenger.send("requestDecks")

    def setDecks(self, decks):
        """Set the decks in the Distributed Shuffle AI with the given
        decks"""
        self.shuffledDeck.setDecks(decks)
        base.messenger.send("Server-is-up")
