from direct.showbase.ShowBase import ShowBase
from Server import SNCServerRepository
from direct.showbase.DirectObject import DirectObject
from MainMenu import MainMenu
from Game import Game
class Main(ShowBase, DirectObject):
	"""Main class of the application
	initialise the engine (ShowBase)"""

	def __init__(self):
		"""initialise the engine"""
		ShowBase.__init__(self)
		# initialize the main menu
		menu = MainMenu()
		self.acceptAll()
		self.disableMouse()
		self.setBackgroundColor(0,0,0)

	def acceptAll(self):
		"""Accept all events that have to be catched by the main class"""
		self.accept("host", self.host)
		self.accept("join", self.join)
		self.accept("quit", self.quit)
		self.accept("escape", self.quit)

	def host(self):
		"""starting the server"""
		# instantiate the server repository
		self.sr = SNCServerRepository()
		# now import the AI repository and instantiate it
		from ShuffleAIRepository import ShuffleAIRepository
		self.shuffleAIRepo = ShuffleAIRepository()
		# accept the request decks event to set a new shuffled deck in
		# the AI repo
		self.accept("requestDecks", self.shuffleDecks)

	def shuffleDecks(self):
		"""Shuffle the card decks and set them in the AI repository"""
		newDeck = self.sr.getShuffledDecks()
		self.shuffleAIRepo.setDecks(newDeck)

	def join(self, ip):
		"""starting the client"""
		# instantiate the client
		from Client import Client
		Client(ip)
		Game()

	def quit(self):
		"""Quit the game"""
		if self.appRunner:
			self.appRunner.stop()
		else:
			exit(0)

# instantiate the engine
base = Main()

# starting the application
if __name__ == '__main__':
    # start the application
    base.run()
